==> igniteui-react-16.16.2.tgz: package/esm5/lib/Card.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var Card = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Card, _super);
    function Card() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = new WCNativeHelper();
        _this.d = null;
        return _this;
    }
    Object.defineProperty(Card.prototype, "b", {
        get: function () {
            return this.a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Card.prototype, "nativeElement", {
        get: function () {
            return this.d;
        },
        set: function (a) {
            this.d = a;
            this.a.d = this.d;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Card.prototype, "c", {
        get: function () {
            var ret_ = this.b.c("elevated");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.i("elevated", value_);
        },
        enumerable: false,
        configurable: true
    });
    Card.$t = markType(Card, 'Card', BaseElement.$);
    return Card;
}(BaseElement));
export { Card };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/Card.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var Card = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Card, _super);
    function Card() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = new WCNativeHelper();
        _this.d = null;
        return _this;
    }
    Object.defineProperty(Card.prototype, "b", {
        get: function () {
            return this.a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Card.prototype, "nativeElement", {
        get: function () {
            return this.d;
        },
        set: function (a) {
            this.d = a;
            this.a.o = this.d;
        },
        enumerable: false,
        configurable: true
    });
    Card.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(Card.prototype, "c", {
        get: function () {
            var ret_ = this.b.n("elevated");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.v("elevated", value_);
        },
        enumerable: false,
        configurable: true
    });
    Card.$t = markType(Card, 'Card', BaseElement.$);
    return Card;
}(BaseElement));
export { Card };
